package com.aucma.production.service;

import java.util.List;
import com.aucma.production.domain.MrpProdWeeklyPlan;

/**
 * 周排产计划Service接口
 * 
 * @author Yinq
 * @date 2026-01-05
 */
public interface IMrpProdWeeklyPlanService 
{
    /**
     * 查询周排产计划
     * 
     * @param id 周排产计划主键
     * @return 周排产计划
     */
    public MrpProdWeeklyPlan selectMrpProdWeeklyPlanById(Long id);

    /**
     * 查询周排产计划列表
     * 
     * @param mrpProdWeeklyPlan 周排产计划
     * @return 周排产计划集合
     */
    public List<MrpProdWeeklyPlan> selectMrpProdWeeklyPlanList(MrpProdWeeklyPlan mrpProdWeeklyPlan);

    /**
     * 新增周排产计划
     * 
     * @param mrpProdWeeklyPlan 周排产计划
     * @return 结果
     */
    public int insertMrpProdWeeklyPlan(MrpProdWeeklyPlan mrpProdWeeklyPlan);

    /**
     * 修改周排产计划
     * 
     * @param mrpProdWeeklyPlan 周排产计划
     * @return 结果
     */
    public int updateMrpProdWeeklyPlan(MrpProdWeeklyPlan mrpProdWeeklyPlan);

    /**
     * 批量删除周排产计划
     * 
     * @param ids 需要删除的周排产计划主键集合
     * @return 结果
     */
    public int deleteMrpProdWeeklyPlanByIds(Long[] ids);

    /**
     * 删除周排产计划信息
     * 
     * @param id 周排产计划主键
     * @return 结果
     */
    public int deleteMrpProdWeeklyPlanById(Long id);

    /**
     * 导入周排产计划数据
     * 
     * @param list 数据列表
     * @param updateSupport 是否更新已存在数据
     * @param operName 操作人
     * @param weekStartDate 周一日期（yyyy-MM-dd格式）
     * @return 结果信息
     */
    public String importData(List<MrpProdWeeklyPlan> list, boolean updateSupport, String operName, String weekStartDate);
}
